==> dde-daemon_5.14.18.orig.tar.xz: dde-daemon-5.14.18/misc/ts/com.deepin.daemon.accounts.policy/policy_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>ཁྱོད་ཀྱི་སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>ཁྱོད་ཀྱི་སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>སྤྱོད་མཁན་གྱི་རྩིས་ཁྲ་དོ་དམ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>ཐོ་རང་འཇུག་བྱེད་པར་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>ཐོ་རང་འཇུག་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>ཐོ་རང་འཇུག་སྒོ་རྒྱག་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>ཐོ་རང་འཇུག་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ་སྒོ་རྒྱག་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>མཐེབ་གཞོང་བཀོད་པ་སྒྲིག་འགོད་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>མཐེབ་གཞོང་བཀོད་པ་སྒྲིག་འགོད་བྱེད་པ།</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.14.97.orig.tar.xz: dde-daemon-5.14.97/misc/ts/com.deepin.daemon.accounts.policy/policy_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="bo" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>ཁྱོད་ཀྱི་སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>ཁྱོད་ཀྱི་སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>སྤྱོད་མཁན་གཞི་གྲངས་བཟོ་བཅོས་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>སྤྱོད་མཁན་གྱི་རྩིས་ཁྲ་དོ་དམ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>ཐོ་རང་འཇུག་བྱེད་པར་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>ཐོ་རང་འཇུག་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>ཐོ་རང་འཇུག་སྒོ་རྒྱག་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>ཐོ་རང་འཇུག་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ་སྒོ་རྒྱག་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>གསང་ཨང་མེད་པར་ཐོ་འཇུག་བྱེད་པ་སྒོ་རྒྱག་པ།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>མཐེབ་གཞོང་སྒྲིག་འགོད་བྱེད་ཚེ་ར་སྤྲོད་བྱེད་དགོས།</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>མཐེབ་གཞོང་བཀོད་པ་སྒྲིག་འགོད་བྱེད་པ།</translation>
		</message>
	</context>
</TS>
